@@ -4,7 +4,7 @@
 modname = 'vcsfile'
 distname = "cubicweb-%s" % modname
 
-numversion = (1, 17, 0)
+numversion = (2, 0, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -22,7 +22,8 @@ classifiers = [
 __depends__ = {'cubicweb': '>= 3.19',
                'cubicweb-localperms': '>= 0.1.0',
                'logilab-mtconverter': '>= 0.7.0',
-               'logilab-common': '>= 0.59.0'
+               'logilab-common': '>= 0.59.0',
+               'python-hglib': '>= 1.4',
                }
 
 # packaging ###
