@@ -1,7 +1,7 @@
 """cubicweb-ctl plugin providing the vcscheck command
 
 :organization: Logilab
-:copyright: 2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2013-2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -9,8 +9,6 @@ __docformat__ = "restructuredtext en"
 from cubicweb.cwctl import CWCTL
 from cubicweb.toolsutils import Command
 
-from cubes.vcsfile.hooks import repo_cache_dir
-
 class VCSRefreshCommand(Command):
     """ Refresh repository
 
@@ -31,11 +29,10 @@ class VCSRefreshCommand(Command):
         config.__class__.cubicweb_appobject_path = set(('hooks', 'entities'))
         repo, cnx = repo_cnx(config)
 
-        rset = cnx.request().execute('Any X,S where X is Repository, X source_url S')
-        ## rest contains only one result because a CW instance cannot have
-        ## two hg repo with the same source_url
-        for hgrepo, source_url in rset:
-            print 'refreshing', source_url
-            cnx.call_service('refresh_repository', eids=hgrepo)
+        with cnx:
+            rset = cnx.execute('Any X,S where X is Repository, X source_url S')
+            for hgrepo, source_url in rset:
+                print 'refreshing', source_url
+                cnx.call_service('refresh_repository', eids=hgrepo)
 
 CWCTL.register(VCSRefreshCommand)
